Troubleshooting — Django Grappelli v1.3 documentation

### Navigation

- index
- next |
- previous |
- Django Grappelli v1.3 documentation »

# Troubleshooting

Sometimes you might have a problem installing/using Grappelli.

## Check your setup

First, please check if the problem is caused by your setup.

- Read Quick start guide and Customization.
- Check if the media-files are served correctly.

## Check issues

If your setup is fine, please check if your problem is a known issue.

- Read Django Issues in order to see if your problem is indeed related to Grappelli.
- Take a look at all Grappelli Issues (incuding closed) and search the Grappelli Google-Group.

## Add a ticket

If you think you’ve found a bug, please add a ticket.

- Try to describe your problem as precisely as possible.
- Tell us what you did in order to solve the problem.
- At best: add a patch.

### Navigation

- index
- next |
- previous |
- Django Grappelli v1.3 documentation »